from setuptools import setup

setup(name='sample_eddie_lin',
      version='0.5',
      description='Sample Package',
      url='https://github.com/informetis/sample-package.git',
      author='EddieLin',
      license='Informetis',
      packages=['sample'],
      zip_safe=False)
